@@ -6,7 +6,14 @@ from dateutil.relativedelta import relativedelta
 import flask
 from functional import memoize, immutable, noop, soak
 from server import single_serve
-import keyring
+
+
+def simplify(value):
+    if isinstance(value, datetime.datetime):
+        return value.isoformat()
+    else:
+        return value
+
 
 def date(obj):
     if obj is None:
